@@ -11,7 +11,7 @@ import time
 class KNativeKafkaConsumer(threading.Thread):
     daemon = True    
 
-    def __init__(self,topics:str,groupid,enable_auto_commit=False):
+    def __init__(self,topics:str,groupid):
 
         """
         Initialize a KNativeKafkaConsumer class based on the input params and the environment variables.
@@ -54,19 +54,21 @@ class KNativeKafkaConsumer(threading.Thread):
             self.ssl_certfile=None
             self.ssl_keyfile=None
         self.logger.info("KafkaConsumer")
+                                                                                                                                                                                                                                                                                                                             
         self.consumer=KafkaConsumer(
                       bootstrap_servers=bootstrap_server,   
-                      group_id=groupid,                                                                                                                                                                                                                                                                                                                          
-                      auto_offset_reset='earliest',
+                      group_id=groupid,     
                       value_deserializer=bytes.decode,
                       security_protocol=self.security_protocol,
+                      ssl_check_hostname=True,
                       ssl_cafile=self.ssl_cafile,
                       ssl_certfile=self.ssl_certfile,
                       ssl_keyfile=self.ssl_keyfile,
+                      auto_offset_reset='earliest',
                       enable_auto_commit=True,
                       auto_commit_interval_ms=1000)
-                          
-        
+ 
+    
     def getMessage(self) -> str:
         """
         Get the message
